Description
===========

A set of modules used for working with EEG event file data. Can load, export and manipulate the data (ready for reuse in EEG analysis software).

Details
-------

Currently can be used for BESA and Neuroscan files
